==> haskell-binary-parser-0.5.5-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-parser
version: 0.5.5
id: binary-parser-0.5.5-EaBFSBxb0XEJII5ytVbu3
key: binary-parser-0.5.5-EaBFSBxb0XEJII5ytVbu3
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/binary-parser
synopsis: A highly-efficient but limited parser API specialised for bytestrings
category: Parser, Binary
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BinaryParser
hidden-modules: BinaryParser.Prelude
abi: 7054ba35c792be513698ae4e12d710ee
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/binary-parser-0.5.5
hs-libraries: HSbinary-parser-0.5.5-EaBFSBxb0XEJII5ytVbu3
depends:
    bytestring-0.10.8.2 text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH transformers-0.5.2.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=208073fa5c5f239d647d4a6aa5951c23
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock
haddock-html: /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-parser-0.5.5-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-parser
version: 0.5.5
id: binary-parser-0.5.5-IE72rHLH3DdBCbmDpZmI42
key: binary-parser-0.5.5-IE72rHLH3DdBCbmDpZmI42
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/binary-parser
synopsis: A highly-efficient but limited parser API specialised for bytestrings
category: Parser, Binary
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    BinaryParser
hidden-modules: BinaryParser.Prelude
abi: ced3bba1b10b3ac8b6c8c7d048ab9bbf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
library-dirs: /usr/lib/ghc-8.2.2/site-local/binary-parser-0.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/binary-parser-0.5.5
hs-libraries: HSbinary-parser-0.5.5-IE72rHLH3DdBCbmDpZmI42
depends:
    bytestring-0.10.8.2 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc transformers-0.5.2.0
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm base-4.10.1.0
abi-depends: bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=ada793ec1f149425d0c0689d53e1173b
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=208073fa5c5f239d647d4a6aa5951c23
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-binary-parser/html/binary-parser.haddock
haddock-html: /usr/share/doc/haskell-binary-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
